@@ -13,8 +13,8 @@
 // [CLASS] Bind
 //============================================================================
 define([
-    'text!vp_base/html/m_apps/bind.html!strip',
-    'css!vp_base/css/m_apps/bind.css',
+    __VP_TEXT_LOADER__('vp_base/html/m_apps/bind.html'), // INTEGRATION: unified version of text loader
+    __VP_CSS_LOADER__('vp_base/css/m_apps/bind'), // INTEGRATION: unified version of css loader
     'vp_base/js/com/com_util',
     'vp_base/js/com/com_String',
     'vp_base/js/com/component/PopupComponent',
@@ -30,6 +30,7 @@ define([
             super._init();
             /** Write codes executed before rendering */
             this.config.sizeLevel = 2;
+            this.config.checkModules = ['pd'];
 
             this.howList = [
                 { label: 'Inner', value: 'inner', desc: 'Inner join' },
@@ -307,7 +308,9 @@ define([
             
             // reset index checkbox event
             $(document).on('change', this.wrapSelector('#vp_bdResetIndex'), function() {
-                that.state.resetIndex = $(this).prop('checked');
+                let isChecked = $(this).prop('checked');
+                $(that.wrapSelector('#vp_bdWithoutColumn')).prop('disabled', !isChecked);
+                that.state.resetIndex = isChecked;
             });
 
             // with/without column select event
@@ -333,7 +336,7 @@ define([
 
         renderDataPage(renderedText, isHtml = true) {
             var tag = new com_String();
-            tag.appendFormatLine('<div class="{0} vp-close-on-blur vp-scrollbar">', 'rendered_html'); // 'rendered_html' style from jupyter output area
+            tag.appendFormatLine('<div class="{0} vp-close-on-blur vp-scrollbar">', 'vp_rendered_html'); // 'rendered_html' style from jupyter output area
             if (isHtml) {
                 tag.appendLine(renderedText);
             } else {
@@ -407,6 +410,7 @@ define([
             variableInput.setSuggestList(function () { return mappedList; });
             variableInput.setNormalFilter(true);
             variableInput.setValue(defaultValue);
+            variableInput.addAttribute('required', true);
             $(this.wrapSelector('#' + id)).replaceWith(function() {
                 return variableInput.toTagString();
             });
